Indexes
-------

This page will try to detail each configuration available into :code:`.PyFunceble.yaml` along with the location of where we are looking for the configuration file.

.. include:: core.rst
.. include:: user-agent.rst
.. include:: outputs.rst
.. include:: status.rst
.. include:: http-codes.rst
.. include:: links.rst

